# Generated from the Telepathy spec
"""Copyright (C) 2008 Collabora Ltd.
Copyright (C) 2008 Nokia Corporation

    This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  
"""

import dbus.service


class ChannelInterfaceDeliveryReporting(dbus.service.Interface):
    """\
      This interface extends the Text and Messages interfaces with improved
        sent-message status reporting.

      This interface replaces Text.SendError, adding support for protocols
        where the message content is not echoed back to the sender on
        failure. It also adds support for receiving positive
        acknowledgements, and uses the Messages queue for state-recovery
        (ensuring that incoming delivery reports are not lost if there is not
        currently a process handling them).

      If this interface and the Messages interface are both present,
        clients that support it SHOULD listen for the MessageReceived signal
        to get delivery reports, and ignore the SendError signal on the Text
        interface.

      Delivery reports appear as messages of type
        Channel_Text_Message_Type_Delivery_Report in the Text and Messages
        interfaces. The message in the Text interface SHOULD have the
        Non_Text_Content flag.

      Whenever a message of type Channel_Text_Message_Type_Delivery_Report
        is signalled for a delivery error report, Channel.Type.Text.SendError
        SHOULD also be emitted; whenever Channel.Type.Text.SendError is
        emitted by a channel which supports this interface, a message of type
        Channel_Text_Message_Type_Delivery_Report MUST also be emitted.

      The corresponding message in the Messages interface MUST contain
        "headers" for the delivery report, as specified below, in its
        first Message_Part.

      
        interface (s - DBus_Interface, as defined in the Messages
          interface)
        MUST be the name of this interface.

        message-sender (u - Contact_Handle, as defined in the Messages
          interface)
        MUST be the intended recipient of the original message, if
          available (zero or omitted otherwise), even if the delivery report
          actually came from an intermediate server.

        message-type (u - Channel_Text_Message_Type, as defined in the
          Messages interface)
        MUST be Channel_Text_Message_Type_Delivery_Report.

        delivery-status (u - Delivery_Status)
        The status of the message. All delivery reports MUST contain
          this key in the first Message_Part.

        delivery-token (s - Sent_Message_Token)

        
          An identifier for the message to which this delivery report
            refers. MUST NOT be an empty string. Omitted if not
            available.

          Clients may match this against the token produced by the
            SendMessage method and MessageSent signal on the Messages
            interface. A status report with no token could match any sent
            message, and a sent message with an empty token could match
            any status report. If multiple sent messages match, clients
            SHOULD use some reasonable heuristic.

          
            In an ideal world, we could unambiguously match reports
            against messages; however, deployed protocols are not ideal,
            and not all reports and messages can be matched.
          
        

        delivery-error (u - Channel_Text_Send_Error)
        
          The reason for the failure. MUST be omitted if this was a
          successful delivery; SHOULD be omitted if it would be
          Channel_Text_Send_Error_Unknown.
        

        delivery-echo (aa{sv} - Message_Part[])
        
          The message content, as defined by the Messages interface.
            Omitted if no content is available. Content MAY have been
            truncated, message parts MAY have been removed, and message
            parts MAY have had their content removed (i.e. the message part
            metadata is present, but the 'content' key is not).

          
            Some protocols, like XMPP, echo the failing message back to
            the sender. This is sometimes the only way to match it
            against the sent message, so we include it here.
          

          Unlike in the Messages interface, content not visible
            in the value for this key cannot be retrieved by another
            means, so the connection manager SHOULD be more
            aggressive about including (possibly truncated) message
            content in the 'content' key.

          
            The Messages interface needs to allow all content to be
            retrieved, but in this interface, the content we provide is
            merely a hint; so some is better than none, and it doesn't
            seem worth providing an API as complex as Messages'
            GetPendingMessageContent for the echoed message.
          
        

      

      The second and subsequent Message_Part dictionaries, if present,
        are a human-readable report from the IM service.

      It is an error for this interface to appear on channels of type
        other than Text, or on Text channels without the Messages interface.
        Clients MUST recover from this error by ignoring the presence
        of the DeliveryReporting interface.

      Some example delivery reports in a Python-like syntax (in which
        arrays are indicated by [a, b] and dictionaries by {k1: v1, k2: v2})
        follow.

      
        A minimal delivery report indicating permanent failure of the
          sent message whose token was
          b9a991bd-8845-4d7f-a704-215186f43bb4 for an unknown
          reason
        
[{
# header
'interface': 'org.freedesktop.Telepathy.Channel.Interface.DeliveryReporting',
'message-sender': 123,
'message-type': Channel_Text_Message_Type_Delivery_Report,
'delivery-status': Delivery_Status_Permanently_Failed,
'delivery-token': 'b9a991bd-8845-4d7f-a704-215186f43bb4',
}
# no body
]


        A delivery report where the failed message is echoed back to the
          sender rather than being referenced by ID, and the failure reason
          is that this protocol cannot send messages to offline contacts
          such as the contact with handle 123
        
[{ # header
'interface': 'org.freedesktop.Telepathy.Channel.Interface.DeliveryReporting',
'message-sender': 123,
'message-type': Channel_Text_Message_Type_Delivery_Report,
'delivery-status': Delivery_Status_Temporarily_Failed,
'delivery-error': Channel_Text_Send_Error_Offline,
'delivery-echo':
    [{ # header of original message
    'message-sender': 1,
    'message-sent': 1210067943,
    },
    { # body of original message
    'type': 'text/plain',
    'content': 'Hello, world!',
    }]
  ],

# no body
]


        A maximally complex delivery report: the server reports a bilingual
          human-readable failure message because the user sent a message
          "Hello, world!" with token
          b9a991bd-8845-4d7f-a704-215186f43bb4 to a contact
          with handle 123, but that handle represents a contact who does not
          actually exist
        
[{ # header
'interface': 'org.freedesktop.Telepathy.Channel.Interface.DeliveryReporting',
'message-sender': 123,
'message-type': Channel_Text_Message_Type_Delivery_Report,
'delivery-status': Delivery_Status_Permanently_Failed,
'delivery-error': Channel_Text_Send_Error_Invalid_Contact,
'delivery-token': 'b9a991bd-8845-4d7f-a704-215186f43bb4',
'delivery-echo':
    [{ # header of original message
    'message-sender': 1,
    'message-sent': 1210067943,
    },
    { # body of original message
    'type': 'text/plain',
    'content': 'Hello, world!',
    }]
  ],
},
{ # message from server (alternative in English)
'alternative': '404',
'type': 'text/plain',
'lang': 'en',
'content': 'I have no contact with that name',
},
{ # message from server (alternative in German)
'alternative': '404'.
'type': 'text/plain',
'lang': 'de',
'content', 'Ich habe keinen Kontakt mit diesem Namen',
}
]


        A minimal delivery report indicating successful delivery
          of the sent message whose token was
          b9a991bd-8845-4d7f-a704-215186f43bb4
        
[{
# header
'interface': 'org.freedesktop.Telepathy.Channel.Interface.DeliveryReporting',
'message-sender': 123,
'message-type': Channel_Text_Message_Type_Delivery_Report,
'delivery-status': Delivery_Status_Delivered,
'delivery-token': 'b9a991bd-8845-4d7f-a704-215186f43bb4',
}
# no body
]


      
    """

    def __init__(self):
        self._interfaces.add('org.freedesktop.Telepathy.Channel.Interface.DeliveryReporting.DRAFT')

    @dbus.service.method('org.freedesktop.Telepathy.Channel.Interface.DeliveryReporting.DRAFT', in_signature='auuu', out_signature='')
    def SendDeliveryReport(self, Messages, Status, Reason):
        """
        Request that a delivery report is sent for the specified pending
          incoming message. Delivery reports cannot currently be sent for
          messages that have already been acknowledged.

        
          The only use-case I can see for delivery reports on non-pending
            messages is a "read receipt" like in email's RFC 3798. Delivery
            reports on non-pending messages will also need a more complex
            API.

          If they turn out to be needed, we can add a method like
            SendDeliveryReportByContent(aa{sv}: message) and add a flag to
            Delivery_Reporting_Support_Flags indicating that this method is
            implemented.
        

        Clients SHOULD NOT attempt to send delivery reports that are
          not indicated to be supported using the DeliveryReportingSupport
          property.

        Clients MUST NOT attempt to send delivery reports using the
          SendMessage method in the Messages API, and connection managers
          MUST NOT allow this to be done.
      
        """
        raise NotImplementedError
  